{% extends "base.html" %}

{% block title %}Profil{% endblock %}

{% block content %}
<div class="row justify-content-center">
  <div class="col-lg-4 col-md-6">
    <h3>Dein Profil</h3>
    <p>Zur Übersicht zeigen wir dir hier alle von uns gespeicherten
      Informationen an. Deinen Namen und deine E-Mail-Adresse erhalten wir von
      der Universität, daher kannst du sie hier nicht ändern.</p>
    <table class="table">
      <tbody>
        <tr>
          <th scope="row">Name</th>
          <td>{{ fachschaftuser.user.get_full_name }}</td>
        </tr>
        <tr>
          <th scope="row">E-Mail</th>
          <td>{{ fachschaftuser.user.email }}</td>
        </tr>
        <tr>
          <th scope="row">Nickname</th>
          <td>{{ fachschaftuser.nickname }}</td>
        </tr>
        <tr>
          <th scope="row">Geschlecht/Gender</th>
          <td>{{ fachschaftuser.gender }}</td>
        </tr>
        <tr>
          <th scope="row">Studiengang</th>
          <td>{{ fachschaftuser.studiengang }}</td>
        </tr>
        <tr>
          <th scope="row">Studienabschnitt</th>
          <td>{{ fachschaftuser.studienabschnitt }}</td>
        </tr>
      </tbody>
    </table>
    <a class="btn btn-primary" href="{% url 'fsmedhro_core:edit' %}" role="button">Profil bearbeiten</a>
  </div>
</div>
{% endblock %}
