{% extends "base.html" %}

{% load crispy_forms_tags %}

{% block title %}Profil bearbeiten{% endblock %}

{% block content %}
<div class="row justify-content-center">
  <div class="col-lg-4 col-md-6">
    <h3>Profil bearbeiten</h3>
    <p>Falls du eine Option vermisst, melde dich bitte beim Fachschaftsrat.</p>
    <form method="post" action="{% url 'fsmedhro_core:edit' %}">
      {% csrf_token %}
      {{ form|crispy }}
      <button class="btn btn-primary" type="submit">Speichern</button>
    </form>
  </div>
</div>
{% endblock %}
